from typing import Optional

from .options import Options


def parse(text: str) -> str:
    ...


def parse_ext(
    text: str, tables: Optional[bool], footnotes: Optional[bool],
    strikethrough: Optional[bool], tasklists: Optional[bool],
    smart_punctuation: Optional[bool], heading_attribute: Optional[bool]
) -> str:
    ...


class Markdown:
    def __init__(self, options: Options) -> None:
        ...

    def parse(self, text: str) -> str:
        ...


# Configuration file for the Sphinx documentation builder.
#
# For the full list of built-in configuration values, see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Project information -----------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#project-information

import os
import sys

sys.path.insert(0, os.path.abspath('../../mizu'))


project = 'mizu'
copyright = '2022, tuna2134'
author = 'tuna2134'

# -- General configuration ---------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration

extensions = [
    "sphinx.ext.autodoc",
    "sphinx.ext.napoleon"
]

templates_path = ['_templates']
exclude_patterns = []



# -- Options for HTML output -------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output

html_theme = 'furo'
html_static_path = ['_static']



class Options:
    """Options for Markdown parsing.

    Args:
        tables (bool): Enable table parsing.
        footnotes (bool): Enable footnote parsing.
        strikethrough (bool): Enable strikethrough parsing.
        tasklists (bool): Enable tasklist parsing.
        smart_punctuation (bool): Enable smart punctuation parsing.
        heading_attribute (bool): Enable heading attribute parsing.
    """
    tables: bool
    footnotes: bool
    strikethrough: bool
    tasklists: bool
    smart_punctuation: bool
    heading_attribute: bool
    
    def __init__(
        self, *, tables: bool = False, footnotes: bool = False,
        strikethrough: bool = False, tasklists: bool = False,
        smart_punctuation: bool = False, heading_attribute: bool = False
    ) -> None:
        self.tables = tables
        self.footnotes = footnotes
        self.strikethrough = strikethrough
        self.tasklists = tasklists
        self.smart_punctuation = smart_punctuation
        self.heading_attribute = heading_attribute

    @classmethod
    def all(cls) -> "Options":
        """Returns an Options object with all options enabled."""
        return cls(
            tables=True, footnotes=True, strikethrough=True,
            tasklists=True, smart_punctuation=True, heading_attribute=True
        )